@@ -11,28 +11,37 @@ use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::Git::Push;
-our $VERSION = '1.100690';
+our $VERSION = '1.100740';
 # ABSTRACT: push current branch
 
 use Git::Wrapper;
 use Moose;
 use MooseX::Has::Sugar;
-use MooseX::Types::Moose qw{ Str };
+use MooseX::Types::Moose qw{ ArrayRef Str };
 
 with 'Dist::Zilla::Role::AfterRelease';
 
+sub mvp_multivalue_args { qw(push_to) }
 
 # -- attributes
 
-has filename => ( ro, isa=>Str, default => 'Changes' );
+has push_to => (
+  is   => 'ro',
+  isa  => 'ArrayRef[Str]',
+  lazy => 1,
+  default => sub { [ qw(origin) ] },
+);
+
 
 sub after_release {
     my $self = shift;
     my $git  = Git::Wrapper->new('.');
 
     # push everything on remote branch
-    $git->push;
-    $git->push( { tags=>1 } );
+    for my $remote ( @{ $self->push_to } ) { 
+      $git->push( $remote );
+      $git->push( { tags=>1 },  $remote );
+    }
 }
 
 1;
@@ -46,14 +55,14 @@ Dist::Zilla::Plugin::Git::Push - push current branch
 
 =head1 VERSION
 
-version 1.100690
+version 1.100740
 
 =head1 SYNOPSIS
 
 In your F<dist.ini>:
 
     [Git::Push]
-    filename = Changes      ; this is the default
+    push_to = origin      ; this is the default
 
 =head1 DESCRIPTION
 
@@ -64,11 +73,15 @@ The plugin accepts the following options:
 
 =over 4
 
-=item * filename - the name of your changelog file. defaults to F<Changes>.
+=item * 
+
+push_to - the name of the a remote to push to. The default is F<Changes>.
+This may be specified multiple times to push to multiple repositories.
 
 =back
 
 =for Pod::Coverage::TrustPod after_release
+    mvp_multivalue_args
 
 =head1 AUTHOR
 
