@@ -11,7 +11,7 @@ use strict;
 use warnings;
 
 package Dist::Zilla::PluginBundle::Git;
-our $VERSION = '1.100690';
+our $VERSION = '1.100740';
 # ABSTRACT: all git plugins in one go
 
 use Moose;
@@ -52,14 +52,20 @@ Dist::Zilla::PluginBundle::Git - all git plugins in one go
 
 =head1 VERSION
 
-version 1.100690
+version 1.100740
 
 =head1 SYNOPSIS
 
 In your F<dist.ini>:
 
     [@Git]
-    filename = Changes        ; this is the default
+    changelog   = Changes             ; this is the default
+    allow_dirty = dist.ini            ; see Git::Check...
+    allow_dirty = Changes             ; ... and Git::Commit
+    commit_msg  = v%v%n%n%c           ; see Git::Commit
+    tag_format  = %v                  ; see Git::Tag
+    tag_message = %v                  ; see Git::Tag
+    push_to     = origin              ; see Git::Push
 
 =head1 DESCRIPTION
 
